@@ -85,9 +85,9 @@ mendelianCheck = function(x, remove = FALSE, verbose = !remove) {
     # Identify & report male heterozygosity
     even = 2 * seq_along(chromX)
     odd = even - 1
-    maleXhet = allelematr[sex == 1, odd, drop = F] != allelematr[sex == 1, even, drop = F]
+    maleXhet = allelematr[sex == 1, odd, drop = FALSE] != allelematr[sex == 1, even, drop = FALSE]
     if(any(maleXhet)) {
-      maleXhet_errors = which(maleXhet, arr.ind = T)
+      maleXhet_errors = which(maleXhet, arr.ind = TRUE)
       error_males_int = which(sex == 1)[maleXhet_errors[, 1]] # modify first col from index *among males*, to *among all*
       error_markers = maleXhet_errors[, 2]
       for(i in unique.default(error_males_int)) {
