@@ -70,7 +70,9 @@ safe_sample <- function(x, ...) x[sample.int(length(x), ...)]
     cbind(v1, v2, deparse.level = 0)
 }
 
-.rand01 = function(n) sample.int(2, size = n, replace = T) - 1  #random 0/1 vector of length n.
+# Random 0/1 vector of length n
+.rand01 = function(n) sample.int(2, size = n, replace = TRUE) - 1
+
 
 stopifnotSimpleVector = function(x, argname = "x") {
   if(is.null(x))
